==> 0.0.3.tar.gz: lib/provider/home_provider/index_provider/index_provider.dart <==
import 'dart:async';

import 'package:cloud_firestore/cloud_firestore.dart';
import 'package:flutter/material.dart';
import 'package:intl/intl.dart' as formatIntl;
import 'package:mini_app_likewallet/library/address_service.dart';
import 'package:mini_app_likewallet/library/configuration_service.dart';
import 'package:mini_app_likewallet/library/ethcontract.dart';
import 'package:shared_preferences/shared_preferences.dart';

class IndexProvider with ChangeNotifier {
  bool _loading = false;
  double balance = 0.0;
  String balanceRate = '0';
  IAddressService addressService;
  IConfigurationService configETH;
  String mnemonic;
  String address;
  BaseETH eth;
  // StreamController<double> streamController =
  //     StreamController<double>.broadcast();
  // StreamController<String> streamCurrencyAmount =
  //     StreamController<String>.broadcast();
  IndexProvider();

  bool get getLoading => _loading;
  String get getBalanceRate => balanceRate;
  double get getBalance => balance;
  // StreamController<double> get getStreamController => streamController;
  // StreamController<String> get getStreamCurrencyAmount => streamCurrencyAmount;

  setStatus({bool status}) {
    _loading = status;
    notifyListeners();
  }

  setBalance({double value}) {
    balance = value;
    notifyListeners();
  }

  loadBalance() async {
    eth = new EthContract();
    SharedPreferences pref = await SharedPreferences.getInstance();
    configETH = new ConfigurationService(pref);
    addressService = new AddressService(configETH);
    mnemonic = await configETH.getMnemonic();
    if (mnemonic == 'no') {
      print('ดีดไป Login');
    }
    String getPK = addressService.getPrivateKey(mnemonic);
    configETH.setPrivateKey(getPK);
    final address = await addressService.getPublicAddress(getPK);
    configETH.setAddress(address.toString());
    balance = await eth.getBalance(address: address.hex);
    balanceCurrency(balance: balance);
    // streamCurrencyAmount.sink.add(await balanceCurrency(balance: balance));
    notifyListeners();
  }

  balanceCurrency({var balance}) async {
    final f = new formatIntl.NumberFormat("###,###.##");
    String fiat = 'none';
    // String balanceTHB = '0';
    print("balance :" + '${balance}');
    balanceRate = f.format((balance / 100).floorToDouble()).toString();
    notifyListeners();
    // await FirebaseFirestore.instance
    //     .collection('exchangeFiat')
    //     .doc(fiat == 'none' ? "THB-THB" : "THB-" + fiat)
    //     .get()
    //     .then((DocumentSnapshot ds) {
    //   print(ds.data()["main"]);
    //   print("THB-" + fiat);

    // if (fiat == 'THB') {
    //   balanceTHB = f.format((balance / 100).floorToDouble()).toString();
    // }
    // return balanceTHB;
    // else if (fiat == 'LIKE') {
    //   setState(() {
    //     balanceTHB = f.format((balance).floorToDouble()).toString();
    //   });
    //   streamCurrencyAmount.sink.add(balanceTHB);
    // } else if (fiat == 'GOLD') {
    //   setState(() {
    //     balanceTHB = f
    //         .format((balance / 100 / ds.data()["rate"]).floorToDouble())
    //         .toString();
    //   });
    //
    //   streamCurrencyAmount.sink.add(balanceTHB);
    // } else {
    //   setState(() {
    //     balanceTHB = f
    //         .format((balance / 100 * ds.data()["rate"]).floorToDouble())
    //         .toString();
    //   });

    // streamCurrencyAmount.sink.add(balanceTHB);
    // }
    // });
  }
}

==> 0.0.4.tar.gz: lib/provider/home_provider/index_provider/index_provider.dart <==
import 'dart:async';

import 'package:cloud_firestore/cloud_firestore.dart';
import 'package:flutter/material.dart';
import 'package:intl/intl.dart' as formatIntl;
import 'package:minilikewallet/library/address_service.dart';
import 'package:minilikewallet/library/configuration_service.dart';
import 'package:minilikewallet/library/ethcontract.dart';
import 'package:shared_preferences/shared_preferences.dart';
import 'package:provider/provider.dart';

class IndexProvider with ChangeNotifier {
  bool _loading = false;
  double balance = 0.0;
  bool statusGetBalance = false;
  String balanceRate = '0';
  IAddressService addressService;
  IConfigurationService configETH;
  String mnemonic;
  String address;
  BaseETH eth;
  bool login = false;
  // StreamController<double> streamController =
  //     StreamController<double>.broadcast();
  // StreamController<String> streamCurrencyAmount =
  //     StreamController<String>.broadcast();
  IndexProvider();

  bool get getLoading => _loading;
  bool get getStatusBalance => statusGetBalance;
  String get getBalanceRate => balanceRate;
  double get getBalance => balance;
  bool get getLogin => login;
  // StreamController<double> get getStreamController => streamController;
  // StreamController<String> get getStreamCurrencyAmount => streamCurrencyAmount;

  setStatus({bool status}) {
    _loading = status;
    notifyListeners();
  }

  setLogin({bool status}) {
    login = status;
    notifyListeners();
  }

  setBalance({double value}) {
    balance = value;
    notifyListeners();
  }

  setGetBalance({bool status}) {
    statusGetBalance = status;
    notifyListeners();
  }

  setGetLogin({bool status}) {
    login = status;
    notifyListeners();
  }

  loadBalance() async {
    statusGetBalance = true;
    notifyListeners();
    eth = new EthContract();
    SharedPreferences pref = await SharedPreferences.getInstance();
    configETH = new ConfigurationService(pref);
    addressService = new AddressService(configETH);
    mnemonic = await configETH.getMnemonic();
    if (mnemonic == 'no') {
      print('ดีดไป Login');
    }
    String getPK = addressService.getPrivateKey(mnemonic);
    configETH.setPrivateKey(getPK);
    final address = await addressService.getPublicAddress(getPK);
    configETH.setAddress(address.toString());
    balance = await eth.getBalance(address: address.hex);
    statusGetBalance = false;

    balanceCurrency(balance: balance);
    // streamCurrencyAmount.sink.add(await balanceCurrency(balance: balance));
    notifyListeners();
  }

  balanceCurrency({var balance}) async {
    final f = new formatIntl.NumberFormat("###,###.##");
    String fiat = 'none';
    // String balanceTHB = '0';
    print("balance :" + '${balance}');
    balanceRate = f.format((balance / 100).floorToDouble()).toString();
    notifyListeners();
    // await FirebaseFirestore.instance
    //     .collection('exchangeFiat')
    //     .doc(fiat == 'none' ? "THB-THB" : "THB-" + fiat)
    //     .get()
    //     .then((DocumentSnapshot ds) {
    //   print(ds.data()["main"]);
    //   print("THB-" + fiat);

    // if (fiat == 'THB') {
    //   balanceTHB = f.format((balance / 100).floorToDouble()).toString();
    // }
    // return balanceTHB;
    // else if (fiat == 'LIKE') {
    //   setState(() {
    //     balanceTHB = f.format((balance).floorToDouble()).toString();
    //   });
    //   streamCurrencyAmount.sink.add(balanceTHB);
    // } else if (fiat == 'GOLD') {
    //   setState(() {
    //     balanceTHB = f
    //         .format((balance / 100 / ds.data()["rate"]).floorToDouble())
    //         .toString();
    //   });
    //
    //   streamCurrencyAmount.sink.add(balanceTHB);
    // } else {
    //   setState(() {
    //     balanceTHB = f
    //         .format((balance / 100 * ds.data()["rate"]).floorToDouble())
    //         .toString();
    //   });

    // streamCurrencyAmount.sink.add(balanceTHB);
    // }
    // });
  }

  inputCurrency({var balance}) async {
    final f = new formatIntl.NumberFormat("###,###.##");
    String fiat = 'none';
    // String balanceTHB = '0';
    print("balance :" + '${balance}');
    // balanceRate = f.format((balance / 100).floorToDouble()).toString();
    balanceRate = f.format((balance / 100)).toString();
    notifyListeners();
  }
}
